summaryrefslogtreecommitdiffstats
path: root/include/linux/tty_ldisc.h
diff options
context:
space:
mode:
authorRalf Baechle <ralf@linux-mips.org>1997-04-29 21:13:14 +0000
committer <ralf@linux-mips.org>1997-04-29 21:13:14 +0000
commit19c9bba94152148523ba0f7ef7cffe3d45656b11 (patch)
tree40b1cb534496a7f1ca0f5c314a523c69f1fee464 /include/linux/tty_ldisc.h
parent7206675c40394c78a90e74812bbdbf8cf3cca1be (diff)
Import of Linux/MIPS 2.1.36
Diffstat (limited to 'include/linux/tty_ldisc.h')
-rw-r--r--include/linux/tty_ldisc.h14
1 files changed, 6 insertions, 8 deletions
diff --git a/include/linux/tty_ldisc.h b/include/linux/tty_ldisc.h
index 05a33261d..bc8e912ca 100644
--- a/include/linux/tty_ldisc.h
+++ b/include/linux/tty_ldisc.h
@@ -64,13 +64,12 @@
* This function notifies the line discpline that a change has
* been made to the termios stucture.
*
- * int (*select)(struct tty_struct * tty, struct inode * inode,
- * struct file * file, int sel_type,
- * struct select_table_struct *wait);
+ * int (*poll)(struct tty_struct * tty, struct file * file,
+ * poll_table *wait);
*
* This function is called when a user attempts to select on a
* tty device. It is solely the responsibility of the line
* discipline to handle select requests.
*
* void (*receive_buf)(struct tty_struct *, const unsigned char *cp,
* char *fp, int count);
@@ -103,6 +102,7 @@
struct tty_ldisc {
int magic;
+ char *name;
int num;
int flags;
/*
@@ -119,9 +119,7 @@ struct tty_ldisc {
int (*ioctl)(struct tty_struct * tty, struct file * file,
unsigned int cmd, unsigned long arg);
void (*set_termios)(struct tty_struct *tty, struct termios * old);
- int (*select)(struct tty_struct * tty, struct inode * inode,
- struct file * file, int sel_type,
- struct select_table_struct *wait);
+ unsigned int (*poll)(struct tty_struct *, struct file *, poll_table *);
/*
* The following routines are called from below.
@@ -64,13 +64,12 @@
*
- * This function is called when a user attempts to select on a
+ * This function is called when a user attempts to select/poll on a
* tty device. It is solely the responsibility of the line
@@ -64,13 +64,12 @@
* tty device. It is solely the responsibility of the line
- * discipline to handle select requests.
+ * discipline to handle poll requests.
*
* void (*receive_buf)(struct tty_struct *, const unsigned char *cp,